# pySparSDR
Python implementation of SparSDR

[*Khazraee, M., Guddeti, Y., Crow, S., Snoeren, A.C., Levchenko, K., Bharadia, D. and Schulman, A., 2019, June. Sparsdr: Sparsity-proportional backhaul and compute for sdrs. In Proceedings of the 17th Annual International Conference on Mobile Systems, Applications, and Services (pp. 391-403).*](https://cseweb.ucsd.edu/~schulman/docs/mobisys19-sparsdr.pdf)
